


AGENT_PROMPT = (
"""
Your task is to extract informatio from an email thread about a lead.
You will be given a thread of emails between a user and a lead.
Your goal is to extract the following information:
- Black Pearl client ID
- Approval status of the lead
- Credit score of the lead
- Any additional relevant information
"""
)
